PermissionHandler class

Constructors

PermissionHandler()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

permissionsGranted Future<bool?>
Gets the device's Do Not Disturb Access status (Android API 24+).
no setter

Static Methods

openDoNotDisturbSetting() Future<void>
Opens the Do Not Disturb Access settings screen.